use lib 'lib';
use Test;

use-ok 'Matrix::Client';
use-ok 'Matrix::Client::Room';
use-ok 'Matrix::Client::Requester';
use-ok 'Matrix::Response';
use-ok 'Matrix::Client::Exception';
use-ok 'Matrix::Client::MediaStore';

done-testing;
